@@ -105,9 +105,8 @@ def parse_pubkey_payload(data):
     ptr += 1
     if version_number not in SUPPORTED_PUBKEY_PACKET_VERSIONS:
         raise PacketVersionNotSupportedError(
-            "Pubkey packet version '{}' not supported, must be one of {}".format(  # pylint: disable=consider-using-f-string
-                version_number, SUPPORTED_PUBKEY_PACKET_VERSIONS
-            )
+            f"Pubkey packet version '{version_number}' not supported, "
+            f"must be one of {SUPPORTED_PUBKEY_PACKET_VERSIONS}"
         )
 
     # NOTE: Uncomment this line to decode the time of creation
@@ -130,10 +129,10 @@ def parse_pubkey_payload(data):
     # as described in section 5.2.3.21.
     if algorithm not in SUPPORTED_SIGNATURE_ALGORITHMS:
         raise SignatureAlgorithmNotSupportedError(
-            "Signature algorithm '{}' not "  # pylint: disable=consider-using-f-string
+            f"Signature algorithm '{algorithm}' not "
             "supported, please verify that your gpg configuration is creating "
             "either DSA, RSA, or EdDSA signatures (see RFC4880 9.1. Public-Key "
-            "Algorithms).".format(algorithm)
+            "Algorithms)."
         )
 
     keyinfo["type"] = SUPPORTED_SIGNATURE_ALGORITHMS[algorithm]["type"]
@@ -216,8 +215,8 @@ def parse_pubkey_bundle(data):
                 and not key_bundle[PACKET_TYPE_PRIMARY_KEY]["key"]
             ):
                 raise PacketParsingError(
-                    "First packet must be a primary key ('{}'), "  # pylint: disable=consider-using-f-string
-                    "got '{}'.".format(PACKET_TYPE_PRIMARY_KEY, packet_type)
+                    "First packet must be a primary key "
+                    f"('{PACKET_TYPE_PRIMARY_KEY}'), got '{packet_type}'."
                 )
 
             if (
@@ -267,7 +266,8 @@ def parse_pubkey_bundle(data):
                     PACKET_TYPE_USER_ID,
                 ]:
                     if key_bundle[_type]:
-                        # Add to most recently added packet's signatures of matching type
+                        # Add to most recently added packet's
+                        # signatures of matching type
                         key_bundle[_type][next(reversed(key_bundle[_type]))][
                             "signatures"
                         ].append(packet)
@@ -276,31 +276,26 @@ def parse_pubkey_bundle(data):
                 else:
                     # If no packets are available for any of above types (yet), the
                     # signature belongs to the primary key
-                    key_bundle[PACKET_TYPE_PRIMARY_KEY]["signatures"].append(
-                        packet
-                    )
+                    key_bundle[PACKET_TYPE_PRIMARY_KEY]["signatures"].append(packet)
 
             else:
+                packets_list = [
+                    PACKET_TYPE_PRIMARY_KEY,
+                    PACKET_TYPE_USER_ID,
+                    PACKET_TYPE_USER_ATTR,
+                    PACKET_TYPE_SUB_KEY,
+                    PACKET_TYPE_SIGNATURE,
+                ]
                 log.info(
-                    "Ignoring gpg key packet '{}', we only handle packets of "  # pylint: disable=logging-format-interpolation,consider-using-f-string
-                    "types '{}' (see RFC4880 4.3. Packet Tags).".format(
-                        packet_type,
-                        [
-                            PACKET_TYPE_PRIMARY_KEY,
-                            PACKET_TYPE_USER_ID,
-                            PACKET_TYPE_USER_ATTR,
-                            PACKET_TYPE_SUB_KEY,
-                            PACKET_TYPE_SIGNATURE,
-                        ],
-                    )
+                    f"Ignoring gpg key packet '{packet_type}', "
+                    "we only handle packets of "
+                    f"types '{packets_list}' (see RFC4880 4.3. Packet Tags)."
                 )
 
         # Both errors might be raised in parse_packet_header and in this loop
         except (PacketParsingError, IndexError) as e:
-            raise PacketParsingError(  # pylint: disable=raise-missing-from
-                "Invalid public key data at position {}: {}.".format(  # pylint: disable=consider-using-f-string
-                    position, e
-                )
+            raise PacketParsingError(
+                f"Invalid public key data at position {position}: {e}."
             )
 
         # Go to next packet
@@ -362,14 +357,12 @@ def _assign_certified_key_info(bundle):
                 )
                 # verify_signature requires a "keyid" even if it is short.
                 # (see parse_signature_packet for more information about keyids)
-                signature["keyid"] = (
-                    signature["keyid"] or signature["short_keyid"]
-                )
+                signature["keyid"] = signature["keyid"] or signature["short_keyid"]
 
             # TODO: Revise exception taxonomy:
             # It's okay to ignore some exceptions (unsupported algorithms etc.) but
             # we should blow up if a signature is malformed (missing subpackets).
-            except Exception as e:  # pylint: disable=broad-except
+            except Exception as e:
                 log.info(e)
                 continue
 
@@ -377,7 +370,7 @@ def _assign_certified_key_info(bundle):
                 signature["keyid"]
             ):
                 log.info(
-                    "Ignoring User ID certificate issued by '{}'.".format(  # pylint: disable=logging-format-interpolation,consider-using-f-string
+                    "Ignoring User ID certificate issued by '{}'.".format(
                         signature["keyid"]
                     )
                 )
@@ -392,8 +385,9 @@ def _assign_certified_key_info(bundle):
 
             if not is_valid:
                 log.info(
-                    "Ignoring invalid User ID self-certificate issued "  # pylint: disable=logging-format-interpolation,consider-using-f-string
-                    "by '{}'.".format(signature["keyid"])
+                    "Ignoring invalid User ID self-certificate issued by '{}'.".format(
+                        signature["keyid"]
+                    )
                 )
                 continue
 
@@ -434,10 +428,7 @@ def _assign_certified_key_info(bundle):
             if is_primary_user and not tmp_is_primary_user:
                 continue
 
-            if (
-                not sig_creation_time
-                or sig_creation_time < tmp_sig_creation_time
-            ):
+            if not sig_creation_time or sig_creation_time < tmp_sig_creation_time:
                 # This is the most recent certificate that has a validity_period and
                 # doesn't have lower priority in regard to the primary user id flag. We
                 # accept it the keys validty_period, until we get a newer value from
@@ -449,9 +440,7 @@ def _assign_certified_key_info(bundle):
                 sig_creation_time = tmp_sig_creation_time
 
     if validity_period is not None:
-        bundle[PACKET_TYPE_PRIMARY_KEY]["key"][
-            "validity_period"
-        ] = validity_period
+        bundle[PACKET_TYPE_PRIMARY_KEY]["key"]["validity_period"] = validity_period
 
     return bundle[PACKET_TYPE_PRIMARY_KEY]["key"]
 
@@ -493,15 +482,13 @@ def _get_verified_subkeys(bundle):
             )
 
         # TODO: Revise exception taxonomy
-        except Exception as e:  # pylint: disable=broad-except
+        except Exception as e:
             log.info(e)
             continue
 
         # Construct signed content (see RFC4880 section 5.2.4. paragraph 3)
         signed_content = (
-            bundle[PACKET_TYPE_PRIMARY_KEY]["packet"]
-            + b"\x99"
-            + subkey_packet[1:]
+            bundle[PACKET_TYPE_PRIMARY_KEY]["packet"] + b"\x99" + subkey_packet[1:]
         )
 
         # Filter sub key binding signature from other signatures, e.g. subkey
@@ -517,13 +504,11 @@ def _get_verified_subkeys(bundle):
                 )
                 # verify_signature requires a "keyid" even if it is short.
                 # (see parse_signature_packet for more information about keyids)
-                signature["keyid"] = (
-                    signature["keyid"] or signature["short_keyid"]
-                )
+                signature["keyid"] = signature["keyid"] or signature["short_keyid"]
                 key_binding_signatures.append(signature)
 
             # TODO: Revise exception taxonomy
-            except Exception as e:  # pylint: disable=broad-except
+            except Exception as e:
                 log.info(e)
                 continue
         # NOTE: As per the V4 key structure diagram in RFC4880 section 12.1., a
@@ -535,7 +520,7 @@ def _get_verified_subkeys(bundle):
         # an *embedded primary key binding signature*.
         if len(key_binding_signatures) != 1:
             log.info(
-                "Ignoring subkey '{}' due to wrong amount of key binding "  # pylint: disable=logging-format-interpolation,consider-using-f-string
+                "Ignoring subkey '{}' due to wrong amount of key binding "
                 "signatures ({}), must be exactly 1.".format(
                     subkey["keyid"], len(key_binding_signatures)
                 )
@@ -550,7 +535,7 @@ def _get_verified_subkeys(bundle):
 
         if not is_valid:
             log.info(
-                "Ignoring subkey '{}' due to invalid key binding signature.".format(  # pylint: disable=logging-format-interpolation,consider-using-f-string
+                "Ignoring subkey '{}' due to invalid key binding signature.".format(
                     subkey["keyid"]
                 )
             )
@@ -559,9 +544,7 @@ def _get_verified_subkeys(bundle):
         # If the signature is valid, we may also extract relevant information from
         # its "info" field (e.g. subkey expiration date) and assign to it to the
         # subkey here
-        validity_period = signature["info"]["subpackets"].get(
-            KEY_EXPIRATION_SUBPACKET
-        )
+        validity_period = signature["info"]["subpackets"].get(KEY_EXPIRATION_SUBPACKET)
         if validity_period is not None:
             subkey["validity_period"] = struct.unpack(">I", validity_period)[0]
 
@@ -610,8 +593,7 @@ def get_pubkey_bundle(data, keyid):
     """
     if not data:
         raise KeyNotFoundError(
-            "Could not find gpg key '{}' in empty exported key "  # pylint: disable=consider-using-f-string
-            "data.".format(keyid)
+            f"Could not find gpg key '{keyid}' in empty exported key data."
         )
 
     # Parse out master key and subkeys (enriched and verified via certificates
@@ -631,7 +613,7 @@ def get_pubkey_bundle(data, keyid):
         if public_key and public_key["keyid"].endswith(keyid.lower()):
             if idx > 1:
                 log.debug(
-                    "Exporting master key '{}' including subkeys '{}' for"  # pylint: disable=logging-format-interpolation,consider-using-f-string
+                    "Exporting master key '{}' including subkeys '{}' for"
                     " passed keyid '{}'.".format(
                         master_public_key["keyid"],
                         ", ".join(list(sub_public_keys.keys())),
@@ -642,9 +624,7 @@ def get_pubkey_bundle(data, keyid):
 
     else:
         raise KeyNotFoundError(
-            "Could not find gpg key '{}' in exported key data.".format(  # pylint: disable=consider-using-f-string
-                keyid
-            )
+            f"Could not find gpg key '{keyid}' in exported key data."
         )
 
     # Add subkeys dictionary to master pubkey "subkeys" field if subkeys exist
@@ -654,7 +634,8 @@ def get_pubkey_bundle(data, keyid):
     return master_public_key
 
 
-def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches,too-many-statements
+# ruff: noqa: PLR0912, PLR0915
+def parse_signature_packet(
     data,
     supported_signature_types=None,
     supported_hash_algorithms=None,
@@ -724,8 +705,8 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
     ptr += 1
     if version_number not in SUPPORTED_SIGNATURE_PACKET_VERSIONS:
         raise ValueError(
-            "Signature version '{}' not supported, must be one of "  # pylint: disable=consider-using-f-string
-            "{}.".format(version_number, SUPPORTED_SIGNATURE_PACKET_VERSIONS)
+            f"Signature version '{version_number}' not supported, "
+            f"must be one of {SUPPORTED_SIGNATURE_PACKET_VERSIONS}."
         )
 
     # Per default we only parse "signatures of a binary document". Other types
@@ -737,10 +718,9 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
 
     if signature_type not in supported_signature_types:
         raise ValueError(
-            "Signature type '{}' not supported, must be one of {} "  # pylint: disable=consider-using-f-string
-            "(see RFC4880 5.2.1. Signature Types).".format(
-                signature_type, supported_signature_types
-            )
+            f"Signature type '{signature_type}' not supported, "
+            f"must be one of {supported_signature_types} "
+            "(see RFC4880 5.2.1. Signature Types)."
         )
 
     signature_algorithm = data[ptr]
@@ -748,10 +728,10 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
 
     if signature_algorithm not in SUPPORTED_SIGNATURE_ALGORITHMS:
         raise ValueError(
-            "Signature algorithm '{}' not "  # pylint: disable=consider-using-f-string
+            f"Signature algorithm '{signature_algorithm}' not "
             "supported, please verify that your gpg configuration is creating "
             "either DSA, RSA, or EdDSA signatures (see RFC4880 9.1. Public-Key "
-            "Algorithms).".format(signature_algorithm)
+            "Algorithms)."
         )
 
     key_type = SUPPORTED_SIGNATURE_ALGORITHMS[signature_algorithm]["type"]
@@ -762,10 +742,9 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
 
     if hash_algorithm not in supported_hash_algorithms:
         raise ValueError(
-            "Hash algorithm '{}' not supported, must be one of {}"  # pylint: disable=consider-using-f-string
-            " (see RFC4880 9.4. Hash Algorithms).".format(
-                hash_algorithm, supported_hash_algorithms
-            )
+            f"Hash algorithm '{hash_algorithm}' not supported, "
+            f"must be one of {supported_hash_algorithms} "
+            "(see RFC4880 9.4. Hash Algorithms)."
         )
 
     # Obtain the hashed octets
@@ -774,11 +753,9 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
     hashed_subpackets = data[ptr : ptr + hashed_octet_count]
     hashed_subpacket_info = gpg_util.parse_subpackets(hashed_subpackets)
 
-    # Check whether we were actually able to read this much hashed octets
     if len(hashed_subpackets) != hashed_octet_count:  # pragma: no cover
         raise ValueError(
-            "This signature packet seems to be corrupted."
-            "It is missing hashed octets!"
+            "Signature packet contains an unexpected amount of hashed octets"
         )
 
     ptr += hashed_octet_count
@@ -862,12 +839,11 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
     # Fail if keyid and short keyid are specified but don't match
     if keyid and not keyid.endswith(short_keyid):  # pragma: no cover
         raise ValueError(
-            "This signature packet seems to be corrupted. The key ID "  # pylint: disable=consider-using-f-string
-            "'{}' of the 'Issuer' subpacket must match the lower 64 bits of the "
-            "fingerprint '{}' of the 'Issuer Fingerprint' subpacket (see RFC4880 "
-            "and rfc4880bis-06 5.2.3.28. Issuer Fingerprint).".format(
-                short_keyid, keyid
-            )
+            "This signature packet seems to be corrupted. The key ID "
+            f"'{short_keyid}' of the 'Issuer' subpacket must match the "
+            f"lower 64 bits of the fingerprint '{keyid}' of the 'Issuer "
+            "Fingerprint' subpacket (see RFC4880 and rfc4880bis-06 5.2.3.28. "
+            "Issuer Fingerprint)."
         )
 
     if not info["creation_time"]:  # pragma: no cover
@@ -886,10 +862,8 @@ def parse_signature_packet(  # pylint: disable=too-many-locals,too-many-branches
     signature = handler.get_signature_params(data[ptr:])
 
     signature_data = {
-        "keyid": "{}".format(keyid),  # pylint: disable=consider-using-f-string
-        "other_headers": binascii.hexlify(data[:other_headers_ptr]).decode(
-            "ascii"
-        ),
+        "keyid": keyid,
+        "other_headers": binascii.hexlify(data[:other_headers_ptr]).decode("ascii"),
         "signature": binascii.hexlify(signature).decode("ascii"),
     }
 
